@@ -1,4 +1,4 @@
-from klongpy.core import *
+from .core import *
 import re
 import sys
 
